/***************************************************************************
 *   Copyright (C) 2008 by Marcel Hasler                                   *
 *   mahasler@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "configbehavior.h"
#include "kosdglobal.h"

#include <kpushbutton.h>
#include <kiconloader.h>
#include <kfiledialog.h>
#include <klocale.h>

#include <qcombobox.h>
#include <qlineedit.h>

ConfigBehavior::ConfigBehavior(QWidget* parent, const char* name, WFlags fl)
: KOSD_BehaviorLayout(parent,name,fl)
{
	m_buttonShortcuts->setIconSet(KGlobal::iconLoader()->loadIcon("configure", KIcon::Small, 0, false));
	m_reloadMixerDeviceList->setPixmap(KGlobal::iconLoader()->loadIcon("reload",KIcon::Small,0,false));
	m_selectMaxBrightnessPath->setPixmap(KGlobal::iconLoader()->loadIcon("fileopen",KIcon::Small,0,false));
	m_selectActualBrightnessPath->setPixmap(KGlobal::iconLoader()->loadIcon("fileopen",KIcon::Small,0,false));
	m_selectChargeFullPath->setPixmap(KGlobal::iconLoader()->loadIcon("fileopen",KIcon::Small,0,false));
	m_selectChargeNowPath->setPixmap(KGlobal::iconLoader()->loadIcon("fileopen",KIcon::Small,0,false));
}


ConfigBehavior::~ConfigBehavior()
{
}


void ConfigBehavior::slotButtonShortcutsClicked()
{
	emit buttonShortcutsClicked();
}


void ConfigBehavior::slotReloadMixerDeviceList()
{
	KOSDGlobal::mixer()->refreshMixerDeviceList();
	m_comboboxMixerDevices->clear();
	m_comboboxMixerDevices->insertStringList(KOSDGlobal::mixer()->mixerDeviceList());
}


void ConfigBehavior::slotSelectMaxBrightnessPath()
{
	QString maxBrightnessPath = KFileDialog::getOpenFileName(m_maxBrightnessPath->text(), "", this, i18n("Select max_brightness"));
	if (maxBrightnessPath != QString::null)
	{
		if (QFile::exists(maxBrightnessPath))
			m_maxBrightnessPath->setText(maxBrightnessPath);
	}
}


void ConfigBehavior::slotSelectActualBrightnessPath()
{
	QString actualBrightnessPath = KFileDialog::getOpenFileName(m_actualBrightnessPath->text(), "", this, i18n("Select actual_brightness"));
	if (actualBrightnessPath != QString::null)
	{
		if (QFile::exists(actualBrightnessPath))
			m_actualBrightnessPath->setText(actualBrightnessPath);
	}
}


void ConfigBehavior::slotSelectChargeFullPath()
{
	QString chargeFullPath = KFileDialog::getOpenFileName(m_chargeFullPath->text(), "", this, i18n("Select charge_full"));
	if (chargeFullPath != QString::null)
	{
		if (QFile::exists(chargeFullPath))
			m_chargeFullPath->setText(chargeFullPath);
	}
}


void ConfigBehavior::slotSelectChargeNowPath()
{
	QString chargeNowPath = KFileDialog::getOpenFileName(m_chargeNowPath->text(), "", this, i18n("Select charge_now"));
	if (chargeNowPath != QString::null)
	{
		if (QFile::exists(chargeNowPath))
			m_chargeNowPath->setText(chargeNowPath);
	}
}


#include "configbehavior.moc"
