/***************************************************************************
 *   Copyright (C) 2008 by Marcel Hasler                                   *
 *   mahasler@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef KOSD_H_
#define KOSD_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <kglobalaccel.h>
#include <kuniqueapplication.h>
#include <kaboutapplication.h>

#include "osd.h"
#include "mixer.h"
#include "configurationdialog.h"

class KOSD : public KUniqueApplication
{
	Q_OBJECT
	K_DCOP
public:
	KOSD();
	~KOSD();

	void initializeConfiguration();
	int newInstance();

private slots:
	void slotRaiseVolume();
	void slotLowerVolume();
	void slotMuteVolume();
	void slotShowVolume();
	void slotShowBrightness();
	void slotShowBrightnessUp();
	void slotShowBrightnessDown();
	void slotShowBattery();
	void slotShowAboutWindow();
	void slotShowConfigWindow();
	void slotDeleteConfigWindow();
	void slotConfigureShortcuts();
	void slotUpdateConfiguration();

private:
	void showBrightnessHelper(OSDType type);
	void quit();

	Mixer *m_mixer;
	KGlobalAccel *m_globalAccel;
	OSD *m_osd;

	QString m_pathToActualBrightness;
	QString m_pathToMaxBrightness;

	QString m_pathToChargeNow;
	QString m_pathToChargeFull;

	unsigned int m_volumeStep;

	ConfigurationDialog *m_configWindow;
	KAboutApplication *m_aboutWindow;

k_dcop:
	// DCOP Functions
	void showVolume(unsigned int percent);
	void showVolumeUp(unsigned int percent);
	void showVolumeDown(unsigned int percent);
	void showVolumeUnmute(unsigned int percent);
	void showVolumeMute();
	void showBrightness(unsigned int percent);
	void showBrightnessUp(unsigned int percent);
	void showBrightnessDown(unsigned int percent);
	void showBattery(unsigned int percent);

	void showVolume();
	void raiseVolume();
	void lowerVolume();
	void muteVolume();
	void showBrightness();
	void showBrightnessUp();
	void showBrightnessDown();
	void showBattery();

	void showCustom(QString iconPath, QString text, unsigned int percent);
};

#endif // KOSD_H_
